<?php

namespace Litecms\TeamMemeber\Providers;

use Illuminate\Support\ServiceProvider;

class TeamMemeberServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'team_memeber');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'team_memeber');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.team_memeber', function ($app) {
            return $this->app->make('Litecms\TeamMemeber\TeamMemeber');
        });

                // Bind TeamMember to repository
        $this->app->bind(
            'Litecms\TeamMemeber\Interfaces\TeamMemberRepositoryInterface',
            \Litecms\TeamMemeber\Repositories\Eloquent\TeamMemberRepository::class
        );

        $this->app->register(\Litecms\TeamMemeber\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\TeamMemeber\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.team_memeber'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/team_memeber.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/team_memeber')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/team_memeber')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
